summaryrefslogtreecommitdiff
path: root/basic/inc/basic/sbstar.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'basic/inc/basic/sbstar.hxx')
-rw-r--r--basic/inc/basic/sbstar.hxx82
1 files changed, 41 insertions, 41 deletions
diff --git a/basic/inc/basic/sbstar.hxx b/basic/inc/basic/sbstar.hxx
index db67836890e9..9eeee5f71d7c 100644
--- a/basic/inc/basic/sbstar.hxx
+++ b/basic/inc/basic/sbstar.hxx
@@ -67,13 +67,13 @@ class StarBASIC : public SbxObject
// Handler-Support:
Link aErrorHdl; // Error handler
Link aBreakHdl; // Breakpoint handler
- BOOL bNoRtl; // if TRUE: do not search RTL
- BOOL bBreak; // if TRUE: Break, otherwise Step
- BOOL bDocBasic;
- BOOL bVBAEnabled;
+ sal_Bool bNoRtl; // if sal_True: do not search RTL
+ sal_Bool bBreak; // if sal_True: Break, otherwise Step
+ sal_Bool bDocBasic;
+ sal_Bool bVBAEnabled;
BasicLibInfo* pLibInfo; // Info block for basic manager
SbLanguageMode eLanguageMode; // LanguageMode of the basic object
- BOOL bQuit;
+ sal_Bool bQuit;
SbxObjectRef pVBAGlobals;
SbxObject* getVBAGlobals( );
@@ -81,19 +81,19 @@ class StarBASIC : public SbxObject
void implClearDependingVarsOnDelete( StarBASIC* pDeletedBasic );
protected:
- BOOL CError( SbError, const String&, xub_StrLen, xub_StrLen, xub_StrLen );
+ sal_Bool CError( SbError, const String&, xub_StrLen, xub_StrLen, xub_StrLen );
private:
- BOOL RTError( SbError, xub_StrLen, xub_StrLen, xub_StrLen );
- BOOL RTError( SbError, const String& rMsg, xub_StrLen, xub_StrLen, xub_StrLen );
- USHORT BreakPoint( xub_StrLen nLine, xub_StrLen nCol1, xub_StrLen nCol2 );
- USHORT StepPoint( xub_StrLen nLine, xub_StrLen nCol1, xub_StrLen nCol2 );
- virtual BOOL LoadData( SvStream&, USHORT );
- virtual BOOL StoreData( SvStream& ) const;
+ sal_Bool RTError( SbError, xub_StrLen, xub_StrLen, xub_StrLen );
+ sal_Bool RTError( SbError, const String& rMsg, xub_StrLen, xub_StrLen, xub_StrLen );
+ sal_uInt16 BreakPoint( xub_StrLen nLine, xub_StrLen nCol1, xub_StrLen nCol2 );
+ sal_uInt16 StepPoint( xub_StrLen nLine, xub_StrLen nCol1, xub_StrLen nCol2 );
+ virtual sal_Bool LoadData( SvStream&, sal_uInt16 );
+ virtual sal_Bool StoreData( SvStream& ) const;
protected:
- virtual BOOL ErrorHdl();
- virtual USHORT BreakHdl();
+ virtual sal_Bool ErrorHdl();
+ virtual sal_uInt16 BreakHdl();
virtual ~StarBASIC();
public:
@@ -101,11 +101,11 @@ public:
SBX_DECL_PERSIST_NODATA(SBXCR_SBX,SBXID_BASIC,1);
TYPEINFO();
- StarBASIC( StarBASIC* pParent = NULL, BOOL bIsDocBasic = FALSE );
+ StarBASIC( StarBASIC* pParent = NULL, sal_Bool bIsDocBasic = sal_False );
// #51727 SetModified overridden so that the Modfied-State is
// not delivered to Parent.
- virtual void SetModified( BOOL );
+ virtual void SetModified( sal_Bool );
void* operator new( size_t );
void operator delete( void* );
@@ -122,14 +122,14 @@ public:
SbModule* MakeModule( const String& rName, const String& rSrc );
SbModule* MakeModule32( const String& rName, const ::rtl::OUString& rSrc );
SbModule* MakeModule32( const String& rName, const com::sun::star::script::ModuleInfo& mInfo, const ::rtl::OUString& rSrc );
- BOOL Compile( SbModule* );
- BOOL Disassemble( SbModule*, String& rText );
+ sal_Bool Compile( SbModule* );
+ sal_Bool Disassemble( SbModule*, String& rText );
static void Stop();
static void Error( SbError );
static void Error( SbError, const String& rMsg );
static void FatalError( SbError );
static void FatalError( SbError, const String& rMsg );
- static BOOL IsRunning();
+ static sal_Bool IsRunning();
static SbError GetErrBasic();
// #66536 make additional message accessible by RTL function Error
static String GetErrorMsg();
@@ -138,7 +138,7 @@ public:
void Highlight( const String& rSrc, SbTextPortions& rList );
virtual SbxVariable* Find( const String&, SbxClassType );
- virtual BOOL Call( const String&, SbxArray* = NULL );
+ virtual sal_Bool Call( const String&, SbxArray* = NULL );
SbxArray* GetModules() { return pModules; }
SbxObject* GetRtl() { return pRtl; }
@@ -147,26 +147,26 @@ public:
void InitAllModules( StarBASIC* pBasicNotToInit = NULL );
void DeInitAllModules( void );
void ClearAllModuleVars( void );
- void ActivateObject( const String*, BOOL );
- BOOL LoadOldModules( SvStream& );
+ void ActivateObject( const String*, sal_Bool );
+ sal_Bool LoadOldModules( SvStream& );
// #43011 For TestTool; deletes global vars
void ClearGlobalVars( void );
// Calls for error and break handler
- static USHORT GetLine();
- static USHORT GetCol1();
- static USHORT GetCol2();
- static void SetErrorData( SbError nCode, USHORT nLine,
- USHORT nCol1, USHORT nCol2 );
+ static sal_uInt16 GetLine();
+ static sal_uInt16 GetCol1();
+ static sal_uInt16 GetCol2();
+ static void SetErrorData( SbError nCode, sal_uInt16 nLine,
+ sal_uInt16 nCol1, sal_uInt16 nCol2 );
// Specific to error handler
static void MakeErrorText( SbError, const String& aMsg );
static const String& GetErrorText();
static SbError GetErrorCode();
- static BOOL IsCompilerError();
- static USHORT GetVBErrorCode( SbError nError );
- static SbError GetSfxFromVBError( USHORT nError );
+ static sal_Bool IsCompilerError();
+ static sal_uInt16 GetVBErrorCode( SbError nError );
+ static SbError GetSfxFromVBError( sal_uInt16 nError );
static void SetGlobalLanguageMode( SbLanguageMode eLangMode );
static SbLanguageMode GetGlobalLanguageMode();
// Local settings
@@ -175,7 +175,7 @@ public:
SbLanguageMode GetLanguageMode();
// Specific for break handler
- BOOL IsBreak() const { return bBreak; }
+ sal_Bool IsBreak() const { return bBreak; }
static Link GetGlobalErrorHdl();
static void SetGlobalErrorHdl( const Link& rNewHdl );
@@ -191,24 +191,24 @@ public:
static SbxBase* FindSBXInCurrentScope( const String& rName );
static SbxVariable* FindVarInCurrentScopy
- ( const String& rName, USHORT& rStatus );
- static SbMethod* GetActiveMethod( USHORT nLevel = 0 );
+ ( const String& rName, sal_uInt16& rStatus );
+ static SbMethod* GetActiveMethod( sal_uInt16 nLevel = 0 );
static SbModule* GetActiveModule();
- void SetVBAEnabled( BOOL bEnabled );
- BOOL isVBAEnabled();
+ void SetVBAEnabled( sal_Bool bEnabled );
+ sal_Bool isVBAEnabled();
- // #60175 TRUE: SFX-Resource is not displayed on basic errors
- static void StaticSuppressSfxResource( BOOL bSuppress );
+ // #60175 sal_True: SFX-Resource is not displayed on basic errors
+ static void StaticSuppressSfxResource( sal_Bool bSuppress );
- // #91147 TRUE: Reschedule is enabled (default>, FALSE: No reschedule
- static void StaticEnableReschedule( BOOL bReschedule );
+ // #91147 sal_True: Reschedule is enabled (default>, sal_False: No reschedule
+ static void StaticEnableReschedule( sal_Bool bReschedule );
SbxObjectRef getRTL( void ) { return pRtl; }
- BOOL IsDocBasic() { return bDocBasic; }
+ sal_Bool IsDocBasic() { return bDocBasic; }
SbxVariable* VBAFind( const String& rName, SbxClassType t );
bool GetUNOConstant( const sal_Char* _pAsciiName, ::com::sun::star::uno::Any& aOut );
void QuitAndExitApplication();
- BOOL IsQuitApplication() { return bQuit; };
+ sal_Bool IsQuitApplication() { return bQuit; };
static ::com::sun::star::uno::Reference< ::com::sun::star::frame::XModel >
GetModelFromBasic( SbxObject* pBasic );